Generate random starts
GenRanStarts(
RanStarts,
nClus,
nBlocks,
ARIlim = 0.2,
itmax = 1000,
verbose = FALSE
)a list where the first element is a matrix with random starts, second element all pairwise ARIs #'
number of randomstarts to generate
number of clusters
number of objects
maximal value of adjusted Rand Index
maximum number of iterations used to find suitable random starts
boolean that indicates whether the output should be printed on the console